@@ -78,12 +78,15 @@ class Saint:
         element has ['과목ID', '과목명', '이수년도', '이수학기', '학점수', '성적기호', '학술연구상태', '제외사유', '신청구분', '신청일', '승인취소일', '신청', '취소'])
         keys
         """
-        sugang = self.sess.get('http://ecc.ssu.ac.kr/sap/bc/webdynpro/SAP/ZCMW2140#')
+        sugang = self.sess.get('https://ecc.ssu.ac.kr/sap/bc/webdynpro/sap/ZCMB3W0017')
         soup = BeautifulSoup(sugang.text, 'html.parser')
         form = soup.find('form', {'name': 'sap.client.SsrClient.form'})
         action = form.get('action')
 
-        table_html = self.sess.post('http://ecc.ssu.ac.kr/sap/bc/webdynpro/SAP/ZCMW2140' + action)
+        action_split = action.split('/sap/bc/webdynpro/sap/ZCMB3W0017?')[1]
+        link = 'https://ecc.ssu.ac.kr/sap/bc/webdynpro/sap/ZCMB3W0017?' + action_split
+        
+        table_html = self.sess.post(link)
         self.soup_jar['grade_table'] = BeautifulSoup(table_html.text, 'lxml')
 
         grade_card = parse_grade_card(self.soup_jar['grade_table'])
@@ -290,6 +293,80 @@ class Saint:
 
         return parse_subjects(self.soup_jar['selective_search'])
 
+    def _select_related_major(self, course_name):
+        """
+        연계전공에서 과목을 선택하고 검색 버튼을 누른다.
+        선행작업:
+        CourseParser.select_course_section('연계전공')
+        :param course_name:
+        :return:
+        """
+
+        course_id = get_related_major_key(self.soup_jar['연계전공'])
+        course_skey = get_related_major_skey(self.soup_jar['연계전공'], course_name)
+        search_id = get_search_id(self.soup_jar['연계전공'])
+        dt_combo_with_search_button_press \
+            = sap_event_queue.combo_select_with_button_press(course_id, course_skey, search_id, self.sap_wd_secure_id)
+        on_selective_liberal_course = self.sess.post(ECC_URL + self.action, data=dt_combo_with_search_button_press)
+        self.soup_jar['related_major_search'] = BeautifulSoup(on_selective_liberal_course.text, 'lxml')
+
+        return parse_subjects(self.soup_jar['related_major_search'])
+    
+    def _select_fusion_major(self, course_name):
+        """
+        융합전공에서 과목을 선택하고 검색 버튼을 누른다.
+        선행작업:
+        CourseParser.select_course_section('융합전공')
+        :param course_name:
+        :return:
+        """
+
+        course_id = get_fusion_major_key(self.soup_jar['융합전공'])
+        course_skey = get_fusion_major_skey(self.soup_jar['융합전공'], course_name)
+        search_id = get_search_id(self.soup_jar['융합전공'])
+        dt_combo_with_search_button_press \
+            = sap_event_queue.combo_select_with_button_press(course_id, course_skey, search_id, self.sap_wd_secure_id)
+        on_selective_liberal_course = self.sess.post(ECC_URL + self.action, data=dt_combo_with_search_button_press)
+        self.soup_jar['fusion_major_search'] = BeautifulSoup(on_selective_liberal_course.text, 'lxml')
+
+        return parse_subjects(self.soup_jar['fusion_major_search'])
+
+    def _select_chapel(self, course_name):
+        """
+        채플에서 과목을 선택하고 검색 버튼을 누른다.
+        선행작업:
+        CourseParser.select_course_section('채플')
+        :param course_name:
+        :return:
+        """
+
+        course_id = get_chapel_key(self.soup_jar['채플'])
+        course_skey = get_chapel_skey(self.soup_jar['채플'], course_name)
+        search_id = get_search_id(self.soup_jar['채플'])
+        dt_combo_with_search_button_press \
+            = sap_event_queue.combo_select_with_button_press(course_id, course_skey, search_id, self.sap_wd_secure_id)
+        on_selective_liberal_course = self.sess.post(ECC_URL + self.action, data=dt_combo_with_search_button_press)
+        self.soup_jar['chapel_search'] = BeautifulSoup(on_selective_liberal_course.text, 'lxml')
+
+        return parse_subjects(self.soup_jar['chapel_search'])
+
+    def _select_teaching(self):
+        """
+        교직에서 검색 버튼을 누른다.
+        선행작업:
+        CourseParser.select_course_section('교직')
+        :param course_name:
+        :return:
+        """
+
+        search_id = get_search_id(self.soup_jar['교직'])
+        dt_search_button_press \
+            = sap_event_queue.button_press(search_id, self.sap_wd_secure_id)
+        on_selective_liberal_course = self.sess.post(ECC_URL + self.action, data=dt_search_button_press)
+        self.soup_jar['teaching_search'] = BeautifulSoup(on_selective_liberal_course.text, 'lxml')
+
+        return parse_subjects(self.soup_jar['teaching_search'])
+
     def _select_liberal_arts(self, course_name):
         """
         선행작업:
@@ -335,6 +412,45 @@ class Saint:
         """
         return self._select_selective_liberal_course(course_name)
 
+    def select_on_related_major(self, course_name):
+        """
+        교양선택에서 과목을 선택해서 검색 정보를 얻는다
+        선행작업:
+        CourseParser.select_course_section('연계전공')
+        :param course_name:
+        :return:
+        """
+        return self._select_related_major(course_name)
+
+    def select_on_fusion_major(self, course_name):
+        """
+        융합전공에서 과목을 선택해서 검색 정보를 얻는다
+        선행작업:
+        CourseParser.select_course_section('융합전공')
+        :param course_name:
+        :return:
+        """
+        return self._select_fusion_major(course_name)
+
+    def select_on_teaching(self):
+        """
+        교직에서 과목을 선택해서 검색 정보를 얻는다
+        선행작업:
+        CourseParser.select_course_section('교직')
+        :return:
+        """
+        return self._select_teaching()
+    
+    def select_on_chapel(self, course_name):
+        """
+        채플에서 과목을 선택해서 검색 정보를 얻는다
+        선행작업:
+        CourseParser.select_course_section('채플')
+        :param course_name:
+        :return:
+        """
+        return self._select_chapel(course_name)
+
     def select_line(self, line):
         """
         줄수/페이지 수를 바꾼다
@@ -421,6 +537,53 @@ class Saint:
 
         return courses
 
+    def get_related_major_map(self):
+        """
+        :TODO :
+        CourseParser.select_course_section('연계전공') 을 처음 실행해서 얻게된
+        self.soup_jar['연계전공'] 에 과목정보가 있는경우가 있고 없는경우가 있다.
+        과목정보가 변경되면 과목정보가 생기고 그대로면 안생기는듯
+        교양선택 맵을 얻는다.
+        선행되야하는 작업:
+        :return:
+        """
+
+        self.select_course_section('연계전공')
+        courses = get_related_major_courses(self.soup_jar['연계전공'])
+
+        return courses
+
+    def get_fusion_major_map(self):
+        """
+        :TODO :
+        CourseParser.select_course_section('융합전공') 을 처음 실행해서 얻게된
+        self.soup_jar['융합전공'] 에 과목정보가 있는경우가 있고 없는경우가 있다.
+        과목정보가 변경되면 과목정보가 생기고 그대로면 안생기는듯
+        교양선택 맵을 얻는다.
+        선행되야하는 작업:
+        :return:
+        """
+
+        self.select_course_section('융합전공')
+        courses = get_fusion_major_courses(self.soup_jar['융합전공'])
+
+        return courses
+
+    def get_chapel_map(self):
+        """
+        :TODO :
+        CourseParser.select_course_section('채플') 을 처음 실행해서 얻게된
+        self.soup_jar['채플'] 에 과목정보가 있는경우가 있고 없는경우가 있다.
+        과목정보가 변경되면 과목정보가 생기고 그대로면 안생기는듯
+        교양선택 맵을 얻는다.
+        선행되야하는 작업:
+        :return:
+        """
+
+        self.select_course_section('채플')
+        courses = get_chapel_courses(self.soup_jar['채플'])
+
+        return courses
 
 if __name__ == '__main__':
     course_parser = Saint()
